Welcome to cdp-scrapers's documentation!
========================================

.. toctree::
   :hidden:
   :maxdepth: 1
   :caption: Contents:

   Overview <self>
   installation
   Searching for your Municipality's Legistar ID <finding_legistar_id.rst>
   LegistarScraper <legistar_scraper.rst>
   Package Modules <modules>
   contributing

.. mdinclude:: ../README.md

Specific Doc Pages
==================

.. autosummary::
   :toctree:
   :caption: Core Components:

   cdp_scrapers.instances.empty.get_events
   cdp_scrapers.legistar_utils.LegistarScraper

Indices and tables
==================
* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
